Struct TopicFilter
#[repr(transparent)]pub struct TopicFilter<S: ?Sized>(S);Expand description
A MQTT topic filter.
This type works as a wrapper around any AsRef<str> type. Typically used as
either a reference (TopicFilter<str>) or an owned string
(TopicFilter<Box<str>>).
All the interesting methods are implemented on the TopicFilter<str>
variant, but other types automatically deref to it.
Tuple Fields
0: SImplementations
impl TopicFilter<str>
impl TopicFilter<str>
pub fn to_boxed_str(&self) -> TopicFilter<Box<str>>
pub fn to_boxed_str(&self) -> TopicFilter<Box<str>>
Converts the topic filter reference into an owned version.
pub fn contains_wildcard(&self) -> bool
pub fn contains_wildcard(&self) -> bool
Returns true if the topic filter contains any wildcard characters.
impl TopicFilter<Box<str>>
impl TopicFilter<Box<str>>
pub const fn to_ref(&self) -> &TopicFilter<str>
pub const fn to_ref(&self) -> &TopicFilter<str>
Converts the owned topic filter into a reference.
impl<S: AsRef<str>> TopicFilter<S>
impl<S: AsRef<str>> TopicFilter<S>
pub fn new(inner: S) -> Self
pub fn new(inner: S) -> Self
Creates a new topic filter wrapping the given inner type.
pub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes the topic filter and returns the inner type.